@@ -174,12 +174,16 @@ void FwupdBackend::addUpdates()
 QByteArray FwupdBackend::getChecksum(const QString &filename, QCryptographicHash::Algorithm hashAlgorithm)
 {
     QFile f(filename);
-    if (!f.open(QFile::ReadOnly))
+    if (!f.open(QFile::ReadOnly)) {
+        qWarning() << "could not open to check" << filename;
         return {};
+    }
 
     QCryptographicHash hash(hashAlgorithm);
-    if (!hash.addData(&f))
+    if (!hash.addData(&f)) {
+        qWarning() << "could not read to check" << filename;
         return {};
+    }
 
     return hash.result().toHex();
 }
@@ -187,7 +191,7 @@ QByteArray FwupdBackend::getChecksum(const QString &filename, QCryptographicHash
 FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
 {
     FwupdRelease *release = fwupd_device_get_release_default(device);
-    FwupdResource* app = createRelease(device);
+    QScopedPointer<FwupdResource> app(createRelease(device));
 
     if (!app->isLiveUpdatable()) {
         qWarning() << "Fwupd Error: " << app->name() << "[" << app->id() << "]" << "cannot be updated ";
@@ -217,24 +221,19 @@ FwupdResource* FwupdBackend::createApp(FwupdDevice *device)
     }
 
     /* Checking for firmware in the cache? */
-    const QString filename_cache = cacheFile(QStringLiteral("fwupd"), QFileInfo(update_uri.path()).fileName());
-    Q_ASSERT(!filename_cache.isEmpty());
-
-    /* Currently LVFS supports SHA1 only*/
-    const QByteArray checksum_tmp(fwupd_checksum_get_by_kind(checksums, G_CHECKSUM_SHA1));
-    const QByteArray checksum = getChecksum(filename_cache, QCryptographicHash::Sha1);
-    if (checksum_tmp != checksum)
-    {
-        qWarning() << "Fwupd Error: " << filename_cache << " does not match checksum, expected" << checksum_tmp << "got" << checksum;
-        QFile::remove(filename_cache);
-        return nullptr;
+    const QString filename_cache = app->cacheFile();
+    if (QFile::exists(filename_cache)) {
+        /* Currently LVFS supports SHA1 only*/
+        const QByteArray checksum_tmp(fwupd_checksum_get_by_kind(checksums, G_CHECKSUM_SHA1));
+        const QByteArray checksum = getChecksum(filename_cache, QCryptographicHash::Sha1);
+        if (checksum_tmp != checksum) {
+            QFile::remove(filename_cache);
+        }
     }
 
-    /* link file to application and return its reference */
-    app->setFile(filename_cache);
     if (!app->needsReboot())
         app->setState(AbstractResource::Upgradeable);
-    return app;
+    return app.take();
 }
 
 bool FwupdBackend::downloadFile(const QUrl &uri, const QString &filename)
@@ -385,12 +384,17 @@ void FwupdBackend::checkForUpdates()
         auto devices = fw->result();
         for(uint i = 0; devices && i < devices->len; i++) {
             FwupdDevice *device = (FwupdDevice *) g_ptr_array_index(devices, i);
+
+            if (!fwupd_device_has_flag (device, FWUPD_DEVICE_FLAG_SUPPORTED))
+                continue;
+
             g_autoptr(GError) error = nullptr;
             g_autoptr(GPtrArray) releases = fwupd_client_get_releases(client, fwupd_device_get_id(device), nullptr, &error);
 
             if (error) {
-                if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE) || g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED))
+                if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE)) {
                     continue;
+                }
 
                 handleError(error);
             }
