@@ -27,7 +27,7 @@
 #include <KShell>
 #include <QList>
 #include <QProcess>
-#include <QDebug>
+#include "libdiscover_debug.h"
 
 AbstractResource::AbstractResource(AbstractResourcesBackend* parent)
     : QObject(parent)
@@ -143,7 +143,8 @@ void AbstractResource::reportNewState()
     if (backend()->isFetching())
         return;
 
-    emit backend()->resourcesChanged(this, {"state", "status", "canUpgrade", "size", "sizeDescription", "installedVersion", "availableVersion" });
+    static const QVector<QByteArray> ns = {"state", "status", "canUpgrade", "size", "sizeDescription", "installedVersion", "availableVersion" };
+    emit backend()->resourcesChanged(this, ns);
 }
 
 static bool shouldFilter(AbstractResource* res, const QPair<FilterType, QString>& filter)
